Description: ErMagicBuilder help window
Keywords: ErMagicBuilderHelp

### Earth-Ref Magic Site Help Window

- Check location name (under the header er_location_name).
- Fill site class (under the header site_class).
  The drop-down menu uses controlled vocabularies from: `site class controlled vocabularies`
  To edit values for the entire column, click the column header. Class can take multiple values in the form of a colon-delimited list, i.e. Extrusive:Igneous. You may use the drop-down menus to add as many values as needed in these columns.
- Fill site lithology (under the header site_lithology).
  Use controlled vocabularies from `site lithology controlled vocabularies`. If you can't find any appropriate definition use: Not Specified.
  To edit values for the entire column, click the column header. Lithology can take multiple values in the form of a colon-delimited list, i.e. Silicate-Sandstone:Silicate-Mud. You may use the drop-down menus to add as many values as needed in these columns.
- Fill site type (under the header site_type).
  Use controlled vocabularies from `site type controlled vocabularies`. If you can't find any appropriate definition use: Not Specified.
  To edit values for the entire column, click the column header. Type can take multiple values in the form of a colon-delimited list, i.e. Baked-Mud:Baked-Rock You may use the drop-down menus to add as many values as needed in these columns.
- Fill site definition (under the header site_definition: the letter "s" for single site or the letter "c" for composite site (including various units).
  To edit values for the entire column, click the column header.
- Fill site longitude (under the header site_lon):Decimal degrees between 0 and 360.
- Fill site latitude (under the header site_lat): Decimal degrees between -90 and 90
- Note: changes to site type, class, etc. will overwrite sample type, class, etc. However, you will be able to specify any differences between (for example) site type and sample type in the next step.